coherence.backends.elisa_renderer (module) — Cohen3 0.8.0 documentation

# coherence.backends.elisa_renderer (module)

class `ElisaPlayer`(server, **kwargs)

  Bases: `coherence.backend.Backend`

  a backend to the Elisa player

  Changed in version 0.9.0:

  - Migrated from louie/dispatcher to EventDispatcher

  - Introduced `Backend`’s inheritance

  `logCategory` = 'elisa_player'
  `implements` = ['MediaRenderer']
  `vendor_value_defaults` = {'RenderingControl': {'A_ARG_TYPE_Channel': 'Master'}}
  `vendor_range_defaults` = {'RenderingControl': {'Volume': {'maximum': 100}}}
  `call_player`(method, callback, *args)
  `poll_player`()
  `query_position`()
  `load`(uri, metadata)
  `start`(uri, metadata=None)
  `stop`()
  `play`()
  `pause`()
  `seek`(location)
    @param location: simple number = time to seek to, in seconds
      +nL = relative seek forward n seconds -nL = relative seek backwards n seconds
  `mute`()
  `unmute`()
  `get_mute`()
  `get_volume`()

    playbin volume is a double from 0.0 - 10.0

  `set_volume`(volume)
  `upnp_init`()

    This method gets called after the device is fired, here all initializations of service related state variables should happen, as the services aren’t available before that point.

  `upnp_Play`(*args, **kwargs)
  `upnp_Pause`(*args, **kwargs)
  `upnp_Stop`(*args, **kwargs)
  `upnp_SetAVTransportURI`(*args, **kwargs)
  `upnp_SetMute`(*args, **kwargs)
  `upnp_SetVolume`(*args, **kwargs)

`main`()